@@ -21,6 +21,7 @@ import (
 	"github.com/koki-develop/gat/internal/prettier"
 	"github.com/koki-develop/gat/internal/styles"
 	"github.com/mattn/go-sixel"
+	"golang.org/x/image/draw"
 )
 
 type Config struct {
@@ -29,6 +30,7 @@ type Config struct {
 	Theme          string
 	RenderMarkdown bool
 	ForceBinary    bool
+	NoResize       bool
 }
 
 type Gat struct {
@@ -37,12 +39,14 @@ type Gat struct {
 	style          *chroma.Style
 	renderMarkdown bool
 	forceBinary    bool
+	noResize       bool
 }
 
 func New(cfg *Config) (*Gat, error) {
 	g := &Gat{
 		renderMarkdown: cfg.RenderMarkdown,
 		forceBinary:    cfg.ForceBinary,
+		noResize:       cfg.NoResize,
 	}
 
 	// lexer
@@ -196,14 +200,33 @@ func (g *Gat) Print(w io.Writer, r io.Reader, opts ...PrintOption) error {
 	return nil
 }
 
-func (*Gat) printImage(w io.Writer, r io.Reader) error {
+func (g *Gat) printImage(w io.Writer, r io.Reader) error {
+	maxEdge := 1800
+
 	img, _, err := image.Decode(r)
 	if err != nil {
 		return err
 	}
+	imgWidth, imgHeight := img.Bounds().Dx(), img.Bounds().Dy()
 
-	if err := sixel.NewEncoder(w).Encode(img); err != nil {
-		return err
+	if g.noResize || (imgWidth <= maxEdge && imgHeight <= maxEdge) {
+		if err := sixel.NewEncoder(w).Encode(img); err != nil {
+			return err
+		}
+	} else {
+		var dstWidth, dstHeight int
+		aspectRatio := float64(imgHeight) / float64(imgWidth)
+		if imgWidth > imgHeight {
+			dstWidth, dstHeight = maxEdge, int(float64(maxEdge)*aspectRatio)
+		} else {
+			dstWidth, dstHeight = int(float64(maxEdge)/aspectRatio), maxEdge
+		}
+
+		dst := image.NewRGBA(image.Rect(0, 0, dstWidth, dstHeight))
+		draw.ApproxBiLinear.Scale(dst, dst.Bounds(), img, img.Bounds(), draw.Src, nil)
+		if err := sixel.NewEncoder(w).Encode(dst); err != nil {
+			return err
+		}
 	}
 
 	return nil
